==> open_swarm-0.1.1744936380.tar.gz: open_swarm-0.1.1744936380/tests/blueprints/test_mission_improbable.py <==
import pytest
import sqlite3
from pathlib import Path
from unittest.mock import patch, MagicMock, AsyncMock

# Assuming BlueprintBase and other necessary components are importable
# from blueprints.mission_improbable.blueprint_mission_improbable import MissionImprobableBlueprint
# from agents import Agent, Runner, RunResult, MCPServer

# Use the same DB path logic as the blueprint
DB_FILE_NAME = "swarm_instructions.db"
DB_PATH = Path(".") / DB_FILE_NAME

@pytest.fixture(scope="function")
def temporary_db_mission():
    """Creates a temporary, empty SQLite DB for testing Mission Improbable."""
    test_db_path = Path("./test_swarm_instructions_mission.db")
    if test_db_path.exists():
        test_db_path.unlink()
    yield test_db_path
    if test_db_path.exists():
        test_db_path.unlink()

@pytest.mark.skip(reason="SQLite interaction testing needs refinement.")
@patch('blueprints.mission_improbable.blueprint_mission_improbable.DB_PATH', new_callable=lambda: Path("./test_swarm_instructions_mission.db"))
@patch('blueprints.mission_improbable.blueprint_mission_improbable.BlueprintBase._load_configuration', return_value={'llm': {'default': {'provider': 'openai', 'model': 'gpt-mock'}}, 'mcpServers': {}})
@patch('blueprints.mission_improbable.blueprint_mission_improbable.BlueprintBase._get_model_instance')
def test_mission_db_initialization(mock_get_model, mock_load_config, temporary_db_mission):
    """Test if the DB table is created and mission sample data loaded."""
    from blueprints.mission_improbable.blueprint_mission_improbable import MissionImprobableBlueprint

    blueprint = MissionImprobableBlueprint(debug=True)
    blueprint._init_db_and_load_data() # Call directly

    assert temporary_db_mission.exists()
    with sqlite3.connect(temporary_db_mission) as conn:
        cursor = conn.cursor()
        cursor.execute("SELECT name FROM sqlite_master WHERE type='table' AND name='agent_instructions';")
        assert cursor.fetchone() is not None
        cursor.execute("SELECT COUNT(*) FROM agent_instructions WHERE agent_name = ?", ("JimFlimsy",))
        assert cursor.fetchone()[0] > 0

@pytest.mark.skip(reason="Blueprint tests not yet implemented")
def test_mission_agent_creation(temporary_db_mission): # Use the specific fixture
    """Test agent creation, assuming DB has data or defaults are used."""
    # Needs mocking of _get_model_instance and potentially _load_configuration
    # Needs instantiation within patched DB_PATH context
    assert False

@pytest.mark.skip(reason="Blueprint interaction tests not yet implemented")
@pytest.mark.asyncio
async def test_mission_delegation_flow(temporary_db_mission):
    """Test a delegation flow, e.g., Jim -> Cinnamon."""
    # Needs Runner mocking, DB mocking/setup.
    assert False

@pytest.mark.skip(reason="Blueprint CLI tests not yet implemented")
def test_mission_cli_execution():
    """Test running the blueprint via CLI."""
    # Needs subprocess testing or direct call to main with mocks.
    assert False

==> open_swarm-0.1.1744952955.tar.gz: open_swarm-0.1.1744952955/tests/blueprints/test_mission_improbable.py <==
import pytest
import sqlite3
from pathlib import Path
from unittest.mock import patch, MagicMock, AsyncMock

# Assuming BlueprintBase and other necessary components are importable
# from blueprints.mission_improbable.blueprint_mission_improbable import MissionImprobableBlueprint
# from agents import Agent, Runner, RunResult, MCPServer

# Use the same DB path logic as the blueprint
DB_FILE_NAME = "swarm_instructions.db"
DB_PATH = Path(".") / DB_FILE_NAME

@pytest.fixture(scope="function")
def temporary_db_mission():
    """Creates a temporary, empty SQLite DB for testing Mission Improbable."""
    test_db_path = Path("./test_swarm_instructions_mission.db")
    if test_db_path.exists():
        test_db_path.unlink()
    yield test_db_path
    if test_db_path.exists():
        test_db_path.unlink()

@pytest.fixture
def mission_blueprint_instance():
    with patch('swarm.core.blueprint_base.BlueprintBase._load_and_process_config', return_value={'llm': {'default': {'provider': 'openai', 'model': 'gpt-mock'}}, 'mcpServers': {}}):
        with patch('swarm.core.blueprint_base.BlueprintBase._get_model_instance') as mock_get_model:
            mock_model_instance = MagicMock()
            mock_get_model.return_value = mock_model_instance
            from swarm.blueprints.mission_improbable.blueprint_mission_improbable import MissionImprobableBlueprint
            # Patch abstract methods to allow instantiation
            MissionImprobableBlueprint.__abstractmethods__ = set()
            instance = MissionImprobableBlueprint(blueprint_id="test_mission", debug=True)
            instance._config = {'llm': {'default': {'provider': 'openai', 'model': 'gpt-mock'}}, 'mcpServers': {}}
            instance.mcp_server_configs = {}
            return instance

@pytest.mark.skip(reason="SQLite interaction testing needs refinement.")
@patch('blueprints.mission_improbable.blueprint_mission_improbable.DB_PATH', new_callable=lambda: Path("./test_swarm_instructions_mission.db"))
@patch('blueprints.mission_improbable.blueprint_mission_improbable.BlueprintBase._load_configuration', return_value={'llm': {'default': {'provider': 'openai', 'model': 'gpt-mock'}}, 'mcpServers': {}})
@patch('blueprints.mission_improbable.blueprint_mission_improbable.BlueprintBase._get_model_instance')
def test_mission_db_initialization(mock_get_model, mock_load_config, temporary_db_mission):
    """Test if the DB table is created and mission sample data loaded."""
    from blueprints.mission_improbable.blueprint_mission_improbable import MissionImprobableBlueprint

    blueprint = MissionImprobableBlueprint(debug=True)
    blueprint._init_db_and_load_data() # Call directly

    assert temporary_db_mission.exists()
    with sqlite3.connect(temporary_db_mission) as conn:
        cursor = conn.cursor()
        cursor.execute("SELECT name FROM sqlite_master WHERE type='table' AND name='agent_instructions';")
        assert cursor.fetchone() is not None
        cursor.execute("SELECT COUNT(*) FROM agent_instructions WHERE agent_name = ?", ("JimFlimsy",))
        assert cursor.fetchone()[0] > 0

def test_mission_agent_creation(mission_blueprint_instance):
    """Test if MissionImprobable agent is created correctly."""
    blueprint = mission_blueprint_instance
    m1 = MagicMock(); m1.name = "memory"
    m2 = MagicMock(); m2.name = "filesystem"
    m3 = MagicMock(); m3.name = "mcp-shell"
    mock_mcp_list = [m1, m2, m3]
    agent = blueprint.create_starting_agent(mcp_servers=mock_mcp_list)
    assert agent is not None
    assert agent.name == "JimFlimsy"

@pytest.mark.skip(reason="Blueprint interaction tests not yet implemented")
@pytest.mark.asyncio
async def test_mission_delegation_flow(temporary_db_mission):
    """Test a delegation flow, e.g., Jim -> Cinnamon."""
    # Needs Runner mocking, DB mocking/setup.
    assert False

@pytest.mark.skip(reason="Blueprint CLI tests not yet implemented")
def test_mission_cli_execution():
    """Test running the blueprint via CLI."""
    # Needs subprocess testing or direct call to main with mocks.
    assert False
